@@ -1,5 +1,6 @@
 # coding:utf-8
 from tools_hjh.ThreadPool import ThreadPool
+from tools_hjh.other import remove_leading_space
 
 
 class DBConn:
@@ -73,6 +74,7 @@ class DBConn:
                                                     encoding=encoding)
     
     def __run(self, sql, param=None):
+        sql = remove_leading_space(sql)
         # 替换占位符
         if self.dbtype == 'pgsql' or self.dbtype == 'mysql':
             sql = sql.replace('?', '%s')
@@ -139,8 +141,10 @@ class DBConn:
         sql中的占位符可以统一使用“?”
         wait为True则会等待当前正在执行的sql，有bug，暂不处理，自用规避"""
         if wait == True:
-            self.runtp.run(self.__run, (sql, param))
+            tpnum = self.runtp.run(self.__run, (sql, param))
             self.runtp.wait()
+            rs = self.runtp.result_map.pop(tpnum)
+            return rs
         else:
             return self.__run(sql, param)
         
@@ -193,7 +197,7 @@ class DBConn:
 
 class QueryResults:
 
-    def __init__(self, cols, rows):
+    def __init__(self, cols=(), rows=[]):
         self.cols = cols
         self.rows = rows
 
@@ -202,3 +206,9 @@ class QueryResults:
 
     def get_rows(self):
         return self.rows
+    
+    def set_cols(self, cols):
+        self.cols = cols
+        
+    def set_rows(self, rows):
+        self.rows = rows
