@@ -2,6 +2,7 @@
 import paramiko
 import os
 import time
+from tools_hjh.other import remove_leading_space
 
 
 class SSHConn:
@@ -22,6 +23,7 @@ class SSHConn:
 
     def exec_command(self, cmd):
         """ 执行单一命令，返回结果 """
+        cmd = remove_leading_space(cmd)
         stdout = self.client.exec_command(cmd)[1]
         return stdout.read().decode("UTF-8").strip()
 
@@ -34,6 +36,7 @@ class SSHConn:
             
         mess = ''
         shell = self.client.invoke_shell()
+        script = remove_leading_space(script)
         shell.send(script + '\n')
         shell.send('exit\n')
         while not shell.exit_status_ready():
